# -*- coding: utf-8 -*-
# Generated by Django 1.11 on 2018-01-29 20:28


from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('enterprise', '0039_auto_20180129_1034'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='enterprisecustomerreportingconfiguration',
            name='initialization_vector',
        ),
        migrations.RemoveField(
            model_name='enterprisecustomerreportingconfiguration',
            name='password',
        ),
        migrations.RemoveField(
            model_name='enterprisecustomerreportingconfiguration',
            name='sftp_password',
        ),
    ]
